#
# spec file for package python-pyzmq
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pyzmq
Version:        14.0.0
Release:        2.1
Summary:        Python bindings for 0MQ
License:        LGPL-3.0+ and BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://github.com/zeromq/pyzmq
Source:         http://pypi.python.org/packages/source/p/pyzmq/pyzmq-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  zeromq-devel
# Test requirements:
BuildRequires:  python-Cython
%if 0%{?suse_version}
Recommends:     zeromq
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
PyZMQ is a lightweight and super-fast messaging library built on top of
the ZeroMQ library (http://www.zeromq.org).

%package devel
Summary:        Development files for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-devel
Requires:       zeromq-devel

%description devel
Development libraries and headers needed to build software using %{name}.

%prep
%setup -q -n pyzmq-%{version}
# Fix non-executable script rpmlint warning:
find examples zmq -name "*.py" -exec sed -i "s|#\!\/usr\/bin\/env python||" {} \;

%build
CFLAGS="%{optflags}" python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

# uses NETLINK which does not exist under linux mode..
%if !0%{?qemu_user_space_build:1}
%check
python setup.py build_ext --inplace
python setup.py test
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.LESSER README.md examples docs
%{python_sitearch}/zmq/
%{python_sitearch}/pyzmq-%{version}-py*.egg-info
%exclude %{python_sitearch}/zmq/utils/*.h

%files devel
%defattr(-,root,root,-)
%{python_sitearch}/zmq/utils/*.h

%changelog
* Thu Apr 18 2019 jbreuer@suse.de
- Gating recommends parameter for Rhel
* Wed Feb 12 2014 dmueller@suse.com
- disable testsuite for qemu-linux-user builds
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 14.0.0
  + Update bundled libzmq to current (4.0.1).
  + Backends are now implemented in ``zmq.backend`` instead of ``zmq.core``.
    This has no effect on public APIs.
  + Various build improvements for Cython and CFFI backends (PyPy
    compiles at build time).
  + Various GIL-related performance improvements - the GIL is no longer
    touched from a zmq IO thread.
  + Adding a constant should now be a bit easier - only zmq/sugar/constant
  _names should need updating,
    all other constant-related files should be automatically updated by
    ``setup.py constants``.
  + add support for latest libzmq-4.0.1
    (includes ZMQ_CURVE security and socket event monitoring).
- Changes from version 13.1.0
  + The main new feature is improved tornado 3 compatibility.
    PyZMQ ships a 'minitornado' submodule, which contains a small
    subset of tornado 3.0.1,
    in order to get the IOLoop base class.  zmq.eventloop.ioloop.IOLoop
    is now a simple subclass, and if the system tornado is ≥ 3.0, then
    the zmq IOLoop is a proper registered subclass of the tornado one itself,
    and minitornado is entirely unused.
- Changes from version 13.0.2
  + EAGAIN was unconditionally turned into KeyboardInterrupt
  + fix use of totally deprecated ctypes_configure to generate constants in CFFI backend
  + fix memory leak in CFFI backend for PyPy
  + typo prevented IPC_PATH_MAX_LEN from ever being defined
  + various build fixes - linking with librt, Cython compatibility, etc.
* Fri Apr 12 2013 toddrme2178@gmail.com
- Changes suggests to recommends since there is no way to install suggets currently
* Fri Apr  5 2013 cfarrell@suse.com
- license update: LGPL-3.0+ and BSD-3-Clause
  the core is LGPL-3.0+ but most of what is outside the code is
  BSD-3-Clause
* Wed Mar 27 2013 speilicke@suse.com
- Update to version 13.0.0:
  + PyPy support
  + The Threadsafe ZMQStream experiment in 2.2.0.1 was deemed inappropriate and not useful,
    and has been removed.
  + The zmq.web experiment has been removed, to be developed as a standalone project
  + Fixes bnc#811890
- Add rpmlintrc
- Drop useless macros
- Run testsuite
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
* Fri Apr 27 2012 highwaystar.ru@gmail.com
- fixed building of python3 package on openSUSE 11.4 and older
* Tue Mar 27 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes. A major feature of libzmq-3.0, the LABEL
    prefix, has been removed from libzmq, prior to the first stable libzmq 3.x release.
  * The prefix argument to ~.Socket.send_multipart remains, but it continue to behave in
    exactly the same way as it always has on 2.1.x, simply prepending message parts.
  * ~.Socket.recv_multipart will always return a list, because prefixes are once
    again indistinguishable from regular message parts.
  * add .Socket.poll method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.  The :class:.ioloop.ZMQPoller class
    is a poller implementation that matches tornado's expectations, and pyzmq sockets can
    be used with any tornado application just by specifying the use of this poller. The
    pyzmq IOLoop implementation now only trivially differs from tornado's.
- Don't package documentation sources
* Tue Jan 31 2012 saschpe@suse.de
- Update to version 2.1.11:
  * remove support for LABEL prefixes.
  * add :meth:`.Socket.poll` method, for simple polling of events on a single socket.
  * no longer require monkeypatching tornado IOLoop.
- Moved Python-3 package into seperate spec file
* Mon Dec  5 2011 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Added python3 subpackage
* Mon Sep 26 2011 cfarrell@suse.com
- license update: LGPL-3.0+
  LGPL is not a recognized license
* Fri Aug 19 2011 saschpe@suse.de
- Update to version 2.1.7:
  * Added proper GIL management for non-copying send
  * Implemented support for zmq_errno().
  * Added Socket.create_socket()
  * Fixed setup.py to work with libzmq.dll on Window
  * The flags argument to Socket.send/Socket.recv must be a C int
    to prevent Python-C API calls in the nogil section.
  * Added a protocol argument to pyobj_send that defaults to -1 (the
    highest pickle protocol).
  * Added a try/finally in Socket.recv.
* Sun Dec 12 2010 saschpe@gmx.de
- Re-generated with py2pack
  * now builds for all RPM-based distros
* Wed Dec  1 2010 saschpe@suse.de
- Initial version (2.0.10).
